@@ -237,8 +237,10 @@ class SCCReader(BaseReader):
             # less than .05s kill it (this is likely caused by a standalone
             # EOC marker in the SCC file)
             if 0 < cap.end - cap.start < 50000:
-                raise ValueError('unsupported length found in SCC '
-                                 f'input file: {cap}')
+                raise CaptionReadTimingError(
+                    f'Unsupported cue duration around {cap.format_start()} '
+                    f'for line beginning with "{cap.get_text()}". Duration '
+                    f'must be at least 0.05 seconds.')
 
         if captions.is_empty():
             raise CaptionReadNoCaptions("empty caption file")
@@ -319,7 +321,9 @@ class SCCReader(BaseReader):
         # up for redundancy in case the signal is garbled in transmission.
         # The decoder is programmed to ignore a second command when it is the
         # same as the first.
-        if word in COMMANDS or _is_pac_command(word):
+        # Also like codes, Special Characters are always doubled up,
+        # with only one member of each pair being displayed.
+        if word in COMMANDS or _is_pac_command(word) or word in SPECIAL_CHARS:
             if word == self.last_command:
                 self.last_command = ''
                 return True
